"""Top-level API for llamabot.

This is the file from which you can do:

    from llamabot import some_function

Use it to control the top-level API of your Python data science project.
"""
from .bot import ChatBot, SimpleBot

__all__ = ["ChatBot", "SimpleBot"]
